# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class BulkOpStatus(str, enum.Enum):
    """
    ℹ️ This enum is non-exhaustive.
    """

    IN_PROGRESS = "in_progress"
    SUCCESS = "success"
    FAILURE = "failure"
    ABORTED = "aborted"
    _UNKNOWN = "__BULKOPSTATUS_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "BulkOpStatus":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        in_progress: typing.Callable[[], T_Result],
        success: typing.Callable[[], T_Result],
        failure: typing.Callable[[], T_Result],
        aborted: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is BulkOpStatus.IN_PROGRESS:
            return in_progress()
        if self is BulkOpStatus.SUCCESS:
            return success()
        if self is BulkOpStatus.FAILURE:
            return failure()
        if self is BulkOpStatus.ABORTED:
            return aborted()
        return _unknown_member(self._value_)
